Documentation
¶
Index ¶
- Variables
- type Printer
- func (p *Printer) Banner()
- func (p *Printer) Blank()
- func (p *Printer) ErrorBox(title, detail string)
- func (p *Printer) Header(text string)
- func (p *Printer) Heartbeat(text string)
- func (p *Printer) KeyValue(key, value string)
- func (p *Printer) PRLink(repo, url string)
- func (p *Printer) Raw(text string)
- func (p *Printer) StepDone(text string)
- func (p *Printer) StepFail(text string)
- func (p *Printer) StepInfo(text string)
- func (p *Printer) StepStart(text string)
- func (p *Printer) StepWarn(text string)
- func (p *Printer) Summary(title string, items []string)
Constants ¶
This section is empty.
Variables ¶
var ( ColorBrand = lipgloss.Color("#7C3AED") ColorSuccess = lipgloss.Color("#10B981") ColorWarning = lipgloss.Color("#F59E0B") ColorError = lipgloss.Color("#EF4444") ColorMuted = lipgloss.Color("#6B7280") ColorInfo = lipgloss.Color("#3B82F6") )
Color constants for consistent terminal styling.
Functions ¶
This section is empty.
Types ¶
type Printer ¶
type Printer struct {
// contains filtered or unexported fields
}
Printer provides styled terminal output. All methods are safe for concurrent use from multiple goroutines.
func (*Printer) Banner ¶
func (p *Printer) Banner()
Banner prints the fullsend brand banner with tagline.
func (*Printer) Heartbeat ¶ added in v0.0.3
Heartbeat prints a periodic progress line in muted color.
func (*Printer) Raw ¶ added in v0.0.3
Raw writes text directly to the output without any styling or indentation.
Click to show internal directories.
Click to hide internal directories.